==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/legacy/UserExtranetArea.php <==
<?php
$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_4d707fab93beb" . "b00bbe69e81596" . "97c90" => base64_decode(""), "_5e30c4717ced36cff9e93e19" . "a5c576cc" => base64_decode("aXNfc3R" . "yaW5n"));
use Claromentis\Core\Services;
use Claromentis\People\Service\UserExtranetService;









class UserExtranetArea implements PeopleGRENamesProvider
{
    
    
    private static $extranet_service;
    
    
    
    
    
    
    
    public static function _Init()
    {
        if (self::$extranet_service === null) {
            self::$extranet_service = Services::I()->GetExtranetService();
        }
    }
    
    
    
    
    
    
    
    public static function GetAll($ids = null)
    {
        return self::$extranet_service->GetAll($ids);
    }
    
    
    
    
    
    
    
    
    public static function CreateNewExtranetArea($name)
    {
        return self::$extranet_service->CreateNewExtranetArea($name);
    }
    
    
    
    
    
    
    
    public static function GetNames($_eb812e836dc420f3d3e36274af306d2d = false)
    {
        global $g_application;
        return self::$extranet_service->GetNames($g_application->security, $_eb812e836dc420f3d3e36274af306d2d);
    }
    
    
    
    
    
    
    
    public static function GetNameById($id, $_724d40caea187c4825bab8a75893a6ea = false)
    {
        global $g_application;
        return self::$extranet_service->GetNameById($id, $g_application->security, $_724d40caea187c4825bab8a75893a6ea);
    }
    public static function GetExareasList($_eb812e836dc420f3d3e36274af306d2d = false)
    {
        return self::GetNames($_eb812e836dc420f3d3e36274af306d2d);
    }
    
    
    
    
    public static function GetPrimary()
    {
        return self::$extranet_service->GetPrimary();
    }
    
    
    
    
    
    
    public static function GetPrimaryId()
    {
        return self::$extranet_service->GetPrimaryId();
    }
    public static function GetDefaultValue()
    {
        return self::$extranet_service->GetDefaultName();
    }
    public static function GetDefaultId()
    {
        return self::$extranet_service->GetDefaultId();
    }
    public static function GetAllMemberIdsById(int $id)
    {
        return self::$extranet_service->GetAllMemberIdsById($id);
    }
    public static function GetIdByUserId($user_id)
    {
        return self::$extranet_service->GetIdByUserId($user_id);
    }
    public static function GetIdByName($_07b8aa45ca4750bcb87a4a5bbef097b6, $_ca46516ac4e37dd733db7dedc3362d53 = false)
    {
        return self::$extranet_service->GetIdByName($_07b8aa45ca4750bcb87a4a5bbef097b6, $_ca46516ac4e37dd733db7dedc3362d53);
    }
    public static function GetCountReadonly()
    {
        return self::$extranet_service->GetCountReadonly();
    }
    public static function GetCountSecondary()
    {
        return self::$extranet_service->GetCountSecondary();
    }
    public function SetFilterKeywords($keywords)
    {
        
        
        if ($keywords === null) {
            $keywords = $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_4d707fab93beb" . "b00bbe69e81596" . "97c90"];
        }
        self::$extranet_service->SetFilterKeywords($keywords);
    }
    
    
    
    
    
    
    public function count()
    {
        global $g_application;
        return self::$extranet_service->GetCount($g_application->security);
    }
    public function GetList($page_size, $_85008ed1ba1db3b691d57c5329e12ac8 = 0)
    {
        global $g_application;
        return self::$extranet_service->GetList($g_application->security, $page_size, $_85008ed1ba1db3b691d57c5329e12ac8);
    }
    
    
    
    
    
    public static function GetExtranetAreasByNames($_bca408ea2d5bd6aea7fc516bb31473f7)
    {
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_5e30c4717ced36cff9e93e1" . "9a5c576cc"]($_bca408ea2d5bd6aea7fc516bb31473f7)) {
            $_bca408ea2d5bd6aea7fc516bb31473f7 = [$_bca408ea2d5bd6aea7fc516bb31473f7];
        }
        return self::$extranet_service->GetExtranetAreasByNames($_bca408ea2d5bd6aea7fc516bb31473f7);
    }
    
    
    
    
    
    public static function GetExtranetAreaNamesById($ids)
    {
        return self::$extranet_service->GetExtranetAreaNamesById($ids);
    }
}


UserExtranetArea::_Init();

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/legacy/UserExtranetArea.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_5e30c4717ced36cff9e93e" . "19a5c576cc" => base64_decode("aXNfc" . "3RyaW" . "5n"), "_4d707fab93bebb00bb" . "e69e8159697c90" => base64_decode(""));
use Claromentis\Core\Services;
use Claromentis\People\Service\UserExtranetService;









class UserExtranetArea implements PeopleGRENamesProvider
{
    
    
    private static $extranet_service;
    
    
    
    
    
    
    
    public static function _Init()
    {
        if (self::$extranet_service === null) {
            self::$extranet_service = Services::I()->GetExtranetService();
        }
    }
    
    
    
    
    
    
    
    public static function GetAll($ids = null)
    {
        return self::$extranet_service->GetAll($ids);
    }
    
    
    
    
    
    
    
    
    public static function CreateNewExtranetArea($name)
    {
        return self::$extranet_service->CreateNewExtranetArea($name);
    }
    
    
    
    
    
    
    
    public static function GetNames($_eb812e836dc420f3d3e36274af306d2d = false)
    {
        global $g_application;
        return self::$extranet_service->GetNames($g_application->security, $_eb812e836dc420f3d3e36274af306d2d);
    }
    
    
    
    
    
    
    
    public static function GetNameById($id, $_724d40caea187c4825bab8a75893a6ea = false)
    {
        global $g_application;
        return self::$extranet_service->GetNameById($id, $g_application->security, $_724d40caea187c4825bab8a75893a6ea);
    }
    public static function GetExareasList($_eb812e836dc420f3d3e36274af306d2d = false)
    {
        return self::GetNames($_eb812e836dc420f3d3e36274af306d2d);
    }
    
    
    
    
    public static function GetPrimary()
    {
        return self::$extranet_service->GetPrimary();
    }
    
    
    
    
    
    
    public static function GetPrimaryId()
    {
        return self::$extranet_service->GetPrimaryId();
    }
    public static function GetDefaultValue()
    {
        return self::$extranet_service->GetDefaultName();
    }
    public static function GetDefaultId()
    {
        return self::$extranet_service->GetDefaultId();
    }
    public static function GetAllMemberIdsById(int $id)
    {
        return self::$extranet_service->GetAllMemberIdsById($id);
    }
    public static function GetIdByUserId($user_id)
    {
        return self::$extranet_service->GetIdByUserId($user_id);
    }
    public static function GetIdByName($_07b8aa45ca4750bcb87a4a5bbef097b6, $_ca46516ac4e37dd733db7dedc3362d53 = false)
    {
        return self::$extranet_service->GetIdByName($_07b8aa45ca4750bcb87a4a5bbef097b6, $_ca46516ac4e37dd733db7dedc3362d53);
    }
    public static function GetCountReadonly()
    {
        return self::$extranet_service->GetCountReadonly();
    }
    public static function GetCountSecondary()
    {
        return self::$extranet_service->GetCountSecondary();
    }
    public function SetFilterKeywords($keywords)
    {
        
        
        if ($keywords === null) {
            $keywords = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_4d707fab93" . "bebb00bbe69" . "e8159697c90"];
        }
        self::$extranet_service->SetFilterKeywords($keywords);
    }
    
    
    
    
    
    
    public function count()
    {
        global $g_application;
        return self::$extranet_service->GetCount($g_application->security);
    }
    public function GetList($page_size, $_85008ed1ba1db3b691d57c5329e12ac8 = 0)
    {
        global $g_application;
        return self::$extranet_service->GetList($g_application->security, $page_size, $_85008ed1ba1db3b691d57c5329e12ac8);
    }
    
    
    
    
    
    public static function GetExtranetAreasByNames($_bca408ea2d5bd6aea7fc516bb31473f7)
    {
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_5e30c4717ced36cff9e93" . "e19a5c576cc"]($_bca408ea2d5bd6aea7fc516bb31473f7)) {
            $_bca408ea2d5bd6aea7fc516bb31473f7 = [$_bca408ea2d5bd6aea7fc516bb31473f7];
        }
        return self::$extranet_service->GetExtranetAreasByNames($_bca408ea2d5bd6aea7fc516bb31473f7);
    }
    
    
    
    
    
    public static function GetExtranetAreaNamesById($ids)
    {
        return self::$extranet_service->GetExtranetAreaNamesById($ids);
    }
}


UserExtranetArea::_Init();
